﻿using System.Linq;
using System.Windows.Controls;
using System.Windows.Data;
using VsiClient.VsiServiceReference;

namespace VsiClient
{
    public partial class MainWindow
    {
        #region Properties

        private ValueList[] ValueListList { get; set; }

        #endregion

        #region Constructors

        public MainWindow()
        {
            this.InitializeComponent();
            this.initialize();
            this.valueListListView.SelectionChanged += this.valueListListViewSelectionChanged;
        }

        #endregion

        #region Event Handler

        private void valueListListViewSelectionChanged(object sender, System.Windows.Controls.SelectionChangedEventArgs e)
        {
            ValueList list = this.valueListListView.SelectedItem as ValueList;
            if (list == null)
            {
                return;
            }
            this.name.Text = list.Name;
            this.description.Text = list.Description;
            this.xmlTag.Text = list.XmlTag;
            this.unit.Text = list.Unit;
            this.valueListValueListView.ItemsSource = list.ValueListValueList.OrderBy(item => item.Name);

            GridView gridView = new GridView();
            gridView.Columns.Add(new GridViewColumn { DisplayMemberBinding = new Binding("ShortName"), Header = "Kürzel" });
            if (list.ValueListType == "StringList")
            {                
                gridView.Columns.Add(new GridViewColumn { DisplayMemberBinding = new Binding("Name"), Header = "Wert" });
            }
            if (list.ValueListType == "IntList")
            {
                gridView.Columns.Add(new GridViewColumn { DisplayMemberBinding = new Binding("ValueInt"), Header = "Wert" });                
            }
            if (list.ValueListType == "FloatList")
            {
                gridView.Columns.Add(new GridViewColumn { DisplayMemberBinding = new Binding("ValueFloat"), Header = "Wert" });
            }

            this.valueListValueListView.View = gridView;
        }

        #endregion

        #region Private Methods

        private void initialize()
        {
            using (VsiServiceClient client = new VsiServiceClient())
            {
                // Laden der Wertelisten über den VSI-Service
                this.ValueListList = client.GetAllValueList();
            }
            this.valueListListView.ItemsSource = this.ValueListList.OrderBy(item => item.Name);
            this.valueListListView.DisplayMemberPath = "Name";

        }

        #endregion
    }
}
